
From: David Brownell <david-b@pacbell.net>

When drives go offline, e.g.  usb-storage disconnect, the upper layers
don't behave very intelligently yet: ext3 over scsi keeps retrying reads,
logging three lines for each error:

10:58:31  scsi0 (0:0): rejecting I/O to dead device
10:58:31  EXT3-fs error (device sda1): ext3_find_entry: reading directory #18089296 offset 0
10:58:31  
10:59:47  EXT3-fs error (device sda1): ext3_find_entry: reading directory #18089296 offset 0

This patch shrinks that log spam by the trivial third, getting rid of those
needless blank lines.  It's not clear to me why the "no such device" errors
don't immediately make ext3 (or is it the block layer?) give up ...  maybe
someone else can make Linux not retry after those errors.

Signed-off-by: David Brownell <dbrownell@users.sourceforge.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/fs/ext3/namei.c |    2 +-
 1 files changed, 1 insertion(+), 1 deletion(-)

diff -puN fs/ext3/namei.c~reduce-ext3-log-spamming-blank-lines fs/ext3/namei.c
--- 25/fs/ext3/namei.c~reduce-ext3-log-spamming-blank-lines	Thu Dec  9 13:07:11 2004
+++ 25-akpm/fs/ext3/namei.c	Thu Dec  9 13:07:11 2004
@@ -872,7 +872,7 @@ restart:
 		if (!buffer_uptodate(bh)) {
 			/* read error, skip block & hope for the best */
 			ext3_error(sb, __FUNCTION__, "reading directory #%lu "
-				   "offset %lu\n", dir->i_ino, block);
+				   "offset %lu", dir->i_ino, block);
 			brelse(bh);
 			goto next;
 		}
_
